setDist method
Set the distance the joint will maintain between the two anchors.
Implementation
void setDist(double dist) => bindings.cpPinJointSetDist(_constraint.toPointer, dist);
Set the distance the joint will maintain between the two anchors.
void setDist(double dist) => bindings.cpPinJointSetDist(_constraint.toPointer, dist);